Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index 7260a1eef4ce1d1954128c6c4c92108ff843aa37..551f12c84c94794357186ef6b41f59203c44fd04 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -2008,11 +2008,13 @@ class JSReceiver: public HeapObject { |
MUST_USE_RESULT static Maybe<bool> HasInPrototypeChain( |
Isolate* isolate, Handle<JSReceiver> object, Handle<Object> proto); |
// Reads all enumerable own properties of source and adds them to target, |
// using either Set or CreateDataProperty depending on the use_set argument. |
MUST_USE_RESULT static Maybe<bool> SetOrCopyDataProperties( |
Isolate* isolate, Handle<JSReceiver> target, Handle<Object> source, |
- bool use_set); |
+ Arguments* excluded_properties = nullptr, bool use_set = true); |
// Implementation of [[HasProperty]], ECMA-262 5th edition, section 8.12.6. |
MUST_USE_RESULT static Maybe<bool> HasProperty(LookupIterator* it); |
@@ -2008,11 +2008,13 @@ class JSReceiver: public HeapObject { |
MUST_USE_RESULT static Maybe<bool> HasInPrototypeChain( |
Isolate* isolate, Handle<JSReceiver> object, Handle<Object> proto); |
- // Reads all enumerable own properties of source and adds them to target, |
- // using either Set or CreateDataProperty depending on the use_set argument. |
+ // Reads all enumerable own properties of source and adds them to |
+ // target, using either Set or CreateDataProperty depending on the |
+ // use_set argument. This only copies values not present in the |
+ // maybe_excluded_properties list. |
MUST_USE_RESULT static Maybe<bool> SetOrCopyDataProperties( |
Isolate* isolate, Handle<JSReceiver> target, Handle<Object> source, |